Cursor

Struct Cursor 

pub struct Cursor<'a> { /* private fields */ }
Zero-copy immutable cursor over source text. Each parse step returns a new advanced cursor.

Implementations

Source

impl<'a> Cursor<'a>

pub fn new(src: &'a str, offset: u32) -> Self

pub fn rest(&self) -> &'a str

pub fn offset(&self) -> u32

pub fn is_empty(&self) -> bool

pub fn first(&self) -> Option<char>

pub fn starts_with(&self, s: &str) -> bool

pub fn span(&self) -> Span

pub fn span_to(&self, end: &Cursor<'_>) -> Span

Create a fallback::Span from this cursor to another.

pub fn slice_to(&self, end: Cursor<'_>) -> &'a str

Get a slice of text from the current cursor to the provided end.

pub fn error(&self) -> LexError

Create an error at the current span

pub fn advance(&self) -> Self

Advance by 1 byte, counting characters for the offset.

pub fn advance_by(&self, n: usize) -> Self

Advance by n bytes, counting characters for the offset.

pub fn skip_while(&self, pred: impl FnMut(char) -> bool) -> Self

Advance while predicate holds on chars.

pub fn skip_whitespace(self) -> Self

pub fn is_line_doc(&self) -> bool

True at a line doc comment: ///... (but not ////...) or //!....

pub fn is_block_doc(&self) -> bool

True at a block doc comment: /**... (but not /***//**/) or /*!....

pub fn doc_comment(&self) -> Option<(Self, bool, String)>

If positioned at a doc comment, return (cursor after it, is_inner, text).

pub fn skip_comment(&self) -> Option<Self>