Module source

Module source 

Source files, locations, and source maps used by spans.

Structs

Location
0 indexed char based location A byte, line, and column location within a source file.
Primarily used to map spans (0 based character index ranges) to bytes. Source text with a stable identifier for span resolution.
SourceMap
A collection of source files used to resolve token locations.