Module span

Module span 

Source-span types and the Spanner trait.

Structs

DelimSpan
The opening and closing spans of a delimited token group.
RangeSpan
A span covering a byte range in a source file.

Enums

Span
A compiler or fallback source span.

Traits

Spanner
Provides the source span occupied by a value.

Functions

line_column_offset