Module source
moxy_
token
0.4.3
Module source
Module Items
Structs
In crate moxy_
token
moxy_token
Module
source
Source files, locations, and source maps used by spans.
Structs

Location
0 indexed char based location A byte, line, and column location within a source file.
Primarily used to map spans (0 based character index ranges) to bytes. Source text with a stable identifier for span resolution.
Map
A collection of source files used to resolve token locations.